스트림 만들고 사용하기
독립적인 작업 큐를 발행합니다.
스트림 만들고 사용하기은(는) CoddyKit의 무료 CUDA Academy 강의입니다. 이것은 4개 중 2번째 강의입니다. 아래에서 전체 강의를 무료로 읽을 수 있으며, 내장 코드 에디터와 24/7 AI 튜터와 함께 브라우저에서 직접 실습할 수 있습니다. 이 강의는 CUDA Academy 학습 경로의 일부이며, 진행 상황이 웹과 CoddyKit 앱에 동기화됩니다. CUDA Academy 강의에는 총 4개의 강의가 포함되어 있습니다.
이 강의의 일부는 아직 번역되지 않았으며 영어로 표시됩니다.
Independent Work Queues
A non-default stream is your own work queue. Two streams run independently, so the GPU can make progress on both at once. 🧵
The Stream Handle
A stream lives in a cudaStream_t handle. You create it once, pass it to your calls, and destroy it when you are done.
cudaStream_t stream;Creating a Stream
Call cudaStreamCreate to make a fresh stream. It allocates the queue the driver uses to schedule that stream's work.
cudaStreamCreate(&stream);Launching a Kernel in a Stream
A kernel's launch config has a fourth argument: shared memory size, then the stream. Pass your stream to queue the kernel there.
kernel<<<grid, block, 0, stream>>>(d_data);Two Streams, Two Tasks
Put one job on streamA and another on streamB. With no dependency between them, the GPU is free to run both concurrently.
kA<<<g, b, 0, streamA>>>(a);
kB<<<g, b, 0, streamB>>>(d);Async by Nature
Stream calls are asynchronous: the host returns immediately and keeps going. The GPU works through the queue on its own time.
Waiting on One Stream
Use cudaStreamSynchronize to block the host until just that stream finishes, instead of waiting on the whole device.
cudaStreamSynchronize(stream);Checking Without Blocking
Want a peek? cudaStreamQuery returns cudaSuccess if the stream is done and cudaErrorNotReady if it is still busy, without stalling you.
cudaStreamQuery(stream);Cleaning Up
When a stream is no longer needed, release it with cudaStreamDestroy. Pending work still completes before the handle is freed.
cudaStreamDestroy(stream);Non-Blocking Streams
Create a stream with the cudaStreamNonBlocking flag so it does not implicitly synchronize with the legacy default stream.
cudaStreamCreateWithFlags(&s, cudaStreamNonBlocking);More Streams, More Overlap
Spreading independent chunks over several streams lets the scheduler keep the engines fed. Beyond a few, returns diminish as hardware fills up.
Quick Check
How do you queue a kernel into a specific stream?
Recap
You can now create streams, launch kernels in them, sync or query, and destroy them. Independent streams unlock real concurrency. ✨
자주 묻는 질문
“스트림 만들고 사용하기” 강의는 무료인가요?
네 — “스트림 만들고 사용하기” 전체 내용을 이 웹사이트에서 무료로 읽을 수 있습니다. 인터랙티브하게 실습하려면(내장 코드 에디터와 24/7 AI 튜터), CoddyKit PRO로 업그레이드하면 CUDA Academy 강의 전체를 잠금 해제할 수 있습니다. CUDA Academy 강의에는 총 4개의 강의가 포함되어 있습니다.
“스트림 만들고 사용하기”에서 뭘 배우나요?
독립적인 작업 큐를 발행합니다. 브라우저에서 직접 실행하는 실습 코드로 CUDA Academy을(를) 배우며, 24/7 AI 튜터가 강의를 진행하면서 질문에 답변해줍니다.
CUDA Academy을(를) 시작하는 데 경험이 필요한가요?
사전 경험은 필요하지 않습니다. CoddyKit의 CUDA Academy은(는) 초급자부터 고급 학습자까지를 위해 구성되어 있으므로, 여기서 시작하거나 처음부터 시작할 수 있으며 자신의 속도대로 진행할 수 있습니다. 이것은 4개 중 2번째 강의입니다.
“스트림 만들고 사용하기” 강의는 얼마나 걸리나요?
대부분의 CoddyKit 강의는 약 5~10분이 소요됩니다. 각 강의는 간결하고 인터랙티브하여 꾸준한 진행이 가능하며, 웹과 앱에서 중단한 부분부터 바로 시작할 수 있습니다.
이 CUDA Academy 강의에서 코드를 작성하고 실행할 수 있나요?
네. 모든 CUDA Academy 강의에는 내장 코드 에디터가 포함되어 있으므로, 브라우저에서 바로 실제 코드를 작성하고 실행한 후 즉시 AI 피드백을 받을 수 있습니다 — 로컬 설정이 필요 없습니다.
이 강의의 모든 강의
- 기본 스트림의 함정
- 스트림 만들고 사용하기
- 시간 측정과 동기화를 위한 이벤트
- 복사와 계산 겹치기